/*
 Analog input reads an analog input on analog in 0, prints the value out.
 created 24 March 2006
 by Tom Igoe
 */
#include <ResponsiveAnalogRead.h>
#include <FastLED.h>
#define LED_PIN     13
#define NUM_LEDS    50
#define DIAL_MIN     20
#define DIAL_MAX    170

const CRGB COLOR_BLACK = CRGB(0, 0, 0);
const CRGB COLOR_RED = CRGB(10, 0, 0);
const CRGB COLOR_YELLOW = CRGB(25, 10, 0);
const CRGB COLOR_GREEN = CRGB(0, 10, 0);
const CRGB COLOR_BLUE = CRGB(0, 0, 10);
const CRGB COLOR_WHITE = CRGB(10, 10, 10);

const int SENSOR_PIN = A0;
ResponsiveAnalogRead analog(SENSOR_PIN, true);
CRGB leds[NUM_LEDS];

void setup() {
  // open the serial port at 9600 bps:
  Serial.begin(9600);
  FastLED.addLeds<WS2812, LED_PIN, GRB>(leds, NUM_LEDS);
}

int analogValue = 0;    // variable to hold the analog value
int val = 0;

void loop() {
  analog.update();  // Updates the ResponsiveAnalogRead object every loop.
  if(analog.hasChanged()) {  // If the responsive value has changes, prints out 'changed'.
    int val = analog.getValue();
    val = map(val, DIAL_MIN, DIAL_MAX, 0, 255);
    int level = val / 51;
    Serial.println(level); // level will be int number ranging [0, 4]
    setPollution(level);
  }
  delay(10);
}

void setPollution(int level) {
    switch (level) {
      case 0:
        setStrip(0, COLOR_RED);
        setStrip(1, COLOR_BLACK);
        setStrip(2, COLOR_BLACK);
        setStrip(3, COLOR_BLACK);
        setStrip(4, COLOR_BLACK);
        break;
      case 1:
        setStrip(0, COLOR_YELLOW);
        setStrip(1, COLOR_YELLOW);
        setStrip(2, COLOR_BLACK);
        setStrip(3, COLOR_BLACK);
        setStrip(4, COLOR_BLACK);
        break;
      case 2:
        setStrip(0, COLOR_GREEN);
        setStrip(1, COLOR_GREEN);
        setStrip(2, COLOR_GREEN);
        setStrip(3, COLOR_BLACK);
        setStrip(4, COLOR_BLACK);
        break;
      case 3:
        setStrip(0, COLOR_BLUE);
        setStrip(1, COLOR_BLUE);
        setStrip(2, COLOR_BLUE);    
        setStrip(3, COLOR_BLUE);  
        setStrip(4, COLOR_BLACK);      
        break;
      case 4:
        setStrip(0, COLOR_WHITE);
        setStrip(1, COLOR_WHITE);
        setStrip(2, COLOR_WHITE);
        setStrip(3, COLOR_WHITE);
        setStrip(4, COLOR_WHITE);
        break;
    }
    FastLED.show();
}

void setStrip(int stripId, CRGB color) {
  for (int i=0;i<10;i++) {
    leds[i+stripId*10] = color;
  }
}
